highspy: Thin set of pybind11 wrappers to HiGHS
===============================================

Description
-----------

Thin set of pybind11 wrappers to HiGHS

License
-------

Upstream Contact
----------------

https://pypi.org/project/highspy/

